@@ -107,14 +107,14 @@
 	       (#t #t)))))
 
 (define (dealable?)
-  (flippable? 0 2))
+  (flippable? 0 1 2))
 
 (define (do-deal-next-cards)
    (flip-stock 0 1 2))
 
 (define (button-clicked slot-id)
-  (if (= slot-id 0)
-      (do-deal-next-cards)))
+  (and (= slot-id 0)
+       (do-deal-next-cards)))
 
 (define (button-double-clicked slot)
   (if (and (not (empty-slot? slot))
