@@ -1274,7 +1274,7 @@ set_sizes (gint size)
 }
 
 static void
-load_theme ()
+load_theme (void)
 {
   if (ball_preimage)
     g_object_unref (ball_preimage);
@@ -1466,7 +1466,7 @@ game_props_callback (void)
     table = gtk_table_new (2, 2, FALSE);
     gtk_container_set_border_width (GTK_CONTAINER (table), 0);
     gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (table), 6);
+    gtk_table_set_col_spacings (GTK_TABLE (table), 12);
     gtk_container_add (GTK_CONTAINER (frame), table);
     gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
 
@@ -1497,8 +1497,7 @@ game_props_callback (void)
 
 
     frame = games_frame_new (_("Board Size"));
-    fv = gtk_vbox_new (FALSE, FALSE);
-    gtk_box_set_spacing (GTK_BOX (fv), 6);
+    fv = gtk_vbox_new (FALSE, 6);
     gtk_container_add (GTK_CONTAINER (frame), fv);
     gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
 
@@ -1517,8 +1516,7 @@ game_props_callback (void)
     }
 
     frame = games_frame_new (C_("preferences", "General"));
-    fv = gtk_vbox_new (FALSE, FALSE);
-    gtk_box_set_spacing (GTK_BOX (fv), 6);
+    fv = gtk_vbox_new (FALSE, 6);
     gtk_container_add (GTK_CONTAINER (frame), fv);
     gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
 
@@ -1786,7 +1784,9 @@ main (int argc, char *argv[])
   if (!games_runtime_init ("glines"))
     return 1;
 
+#ifdef ENABLE_SETGID
   setgid_io_init ();
+#endif
 
   rgen = g_rand_new ();
 
@@ -1862,7 +1862,7 @@ main (int argc, char *argv[])
   gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
 
   table = gtk_table_new (2, 1, TRUE);
-  gtk_box_pack_start_defaults (GTK_BOX (vbox), table);
+  gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), statusbar, FALSE, FALSE, 0);
   hbox = gtk_hbox_new (FALSE, 0);
 
