@@ -30,6 +30,7 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <gdk/gdkkeysyms.h>
 
 #include <libgames-support/games-clock.h>
 #include <libgames-support/games-conf.h>
@@ -38,7 +39,6 @@
 #include <libgames-support/games-runtime.h>
 #include <libgames-support/games-scores.c>
 #include <libgames-support/games-scores-dialog.h>
-#include <libgames-support/games-sound.h>
 #include <libgames-support/games-stock.h>
 
 #ifdef WITH_SMCLIENT
@@ -87,6 +87,7 @@ gint fsize = -1;
 gboolean use_question_marks = TRUE;
 gboolean use_overmine_warning = TRUE;
 gboolean use_autoflag = FALSE;
+gboolean game_paused = FALSE;
 
 GtkAction *hint_action;
 GtkAction *fullscreen_action;
@@ -263,12 +264,12 @@ new_game (void)
   GtkMineField *mf = GTK_MINEFIELD (mfield);
 
   games_clock_stop (GAMES_CLOCK (clk));
-  games_clock_set_seconds (GAMES_CLOCK (clk), 0);
+  games_clock_reset (GAMES_CLOCK (clk));
   show_face (pm_smile);
 
   /* get window size and mine square size (gtk_minefield_restart() may change it) */
   gtk_window_get_size (GTK_WINDOW (window), &width, &height);
-  size = mf->minesize;
+  size = mf->minesizepixels;
   w_diff = width - mfield->allocation.width;
   h_diff = height - mfield->allocation.height;
 
@@ -337,7 +338,7 @@ hint_callback (void)
 static void
 pause_callback (GtkWidget * widget, GdkEventFocus * event, gpointer data)
 {
-  if ((GAMES_CLOCK (clk)->timer_id != 0)
+  if (games_clock_is_started (GAMES_CLOCK (clk))
       && (!disable_hiding)) {
     gtk_widget_hide (mfield_container);
     gtk_widget_show (resume_container);
@@ -347,7 +348,12 @@ pause_callback (GtkWidget * widget, GdkEventFocus * event, gpointer data)
     games_clock_stop (GAMES_CLOCK (clk));
 
     gtk_action_set_visible (pause_action, FALSE);
+    gtk_action_set_sensitive (pause_action, FALSE);
+
     gtk_action_set_visible (resume_action, TRUE);
+    gtk_action_set_sensitive (resume_action, TRUE);
+
+    game_paused = TRUE;
   }
 }
 
@@ -360,7 +366,11 @@ resume_game_cb (GtkButton * widget, gpointer data)
   games_clock_start (GAMES_CLOCK (clk));
 
   gtk_action_set_visible (pause_action, TRUE);
+  gtk_action_set_sensitive(pause_action, TRUE);
   gtk_action_set_visible (resume_action, FALSE);
+  gtk_action_set_sensitive(resume_action, FALSE);
+
+  game_paused = FALSE;
 }
 
 static void
@@ -386,6 +396,7 @@ win_game (GtkWidget * widget, gpointer data)
 {
   GamesScoreValue score;
   int pos;
+  time_t seconds;
 
   games_clock_stop (GAMES_CLOCK (clk));
 
@@ -393,8 +404,8 @@ win_game (GtkWidget * widget, gpointer data)
 
   show_face (pm_win);
 
-  score.time_double = (gfloat) (GAMES_CLOCK (clk)->stopped / 60) +
-    (gfloat) (GAMES_CLOCK (clk)->stopped % 60) / 100;
+  seconds = games_clock_get_seconds (GAMES_CLOCK (clk));
+  score.time_double = (gfloat) (seconds / 60) + (gfloat) (seconds % 60) / 100;
 
   pos = games_scores_add_score (highscores, score);
 
@@ -636,6 +647,23 @@ window_state_callback (GtkWidget * widget, GdkEventWindowState * event)
   return FALSE;
 }
 
+
+static void
+pause_key_callback(GtkWidget *widget, GdkEventKey *event,
+gpointer data )
+{
+
+  if(event->keyval == GDK_Pause)
+  {
+    if(game_paused)
+      resume_game_cb(NULL, NULL); // Resume the game
+    else
+      pause_callback(NULL, NULL, NULL); // Pause the game
+  }
+			
+}
+
+
 static void
 create_preferences (void)
 {
@@ -729,6 +757,8 @@ create_preferences (void)
   gtk_table_attach (GTK_TABLE (table), cframe, 1, 2, 0, 1, GTK_FILL, GTK_FILL,
 		    0, 0);
 
+  frame = games_frame_new(_("Flags"));
+
   question_toggle =
     gtk_check_button_new_with_mnemonic (_("_Use \"I'm not sure\" flags"));
   g_signal_connect (GTK_OBJECT (question_toggle), "toggled",
@@ -737,8 +767,11 @@ create_preferences (void)
 				use_question_marks);
   gtk_widget_show (question_toggle);
 
-  gtk_table_attach_defaults (GTK_TABLE (table), question_toggle, 0, 2, 1, 2);
+  gtk_container_add (GTK_CONTAINER (frame), question_toggle);
 
+  gtk_table_attach_defaults (GTK_TABLE (table), frame, 0, 2, 1, 2);
+
+  frame = games_frame_new(_("Warnings"));
 
   overmine_toggle =
     gtk_check_button_new_with_mnemonic (_("_Use \"Too many flags\" warning"));
@@ -748,8 +781,9 @@ create_preferences (void)
 				use_overmine_warning);
   gtk_widget_show (overmine_toggle);
 
-  gtk_table_attach_defaults (GTK_TABLE (table), overmine_toggle, 0, 2, 2, 3);
+  gtk_container_add (GTK_CONTAINER (frame), overmine_toggle);
 
+  gtk_table_attach_defaults (GTK_TABLE (table), frame, 0, 2, 2, 3);
 
   pref_dialog = gtk_dialog_new_with_buttons (_("Mines Preferences"),
 					     GTK_WINDOW (window),
@@ -773,6 +807,7 @@ create_preferences (void)
   gtk_widget_show_all (GTK_WIDGET (table));
 }
 
+
 static void
 preferences_callback (void)
 {
@@ -971,7 +1006,9 @@ main (int argc, char *argv[])
   if (!games_runtime_init ("gnomine"))
     return 1;
 
+#ifdef ENABLE_SETGID
   setgid_io_init ();
+#endif
 
   context = g_option_context_new (NULL);
 #if GLIB_CHECK_VERSION (2, 12, 0)
@@ -981,7 +1018,6 @@ main (int argc, char *argv[])
 #ifdef WITH_SMCLIENT
   g_option_context_add_group (context, egg_sm_client_get_option_group ());
 #endif /* WITH_SMCLIENT */
-  games_sound_add_option_group (context);
   g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
 
   retval = g_option_context_parse (context, &argc, &argv, &error);
@@ -1054,6 +1090,10 @@ main (int argc, char *argv[])
   g_signal_connect (G_OBJECT (window), "window_state_event",
 		    G_CALLBACK (window_state_callback), NULL);
 
+  // For pause/resume with the keyboard pause key
+  g_signal_connect (G_OBJECT (window), "key_press_event", 
+                    G_CALLBACK (pause_key_callback), NULL); 
+
   all_boxes = gtk_vbox_new (FALSE, 0);
 
   gtk_container_add (GTK_CONTAINER (window), all_boxes);
