@@ -1192,7 +1192,7 @@ new_game (gboolean shuffle)
 
   /* Prepare clock */
   games_clock_stop (GAMES_CLOCK (chrono));
-  games_clock_set_seconds (GAMES_CLOCK (chrono), 0);
+  games_clock_reset (GAMES_CLOCK (chrono));
 
   /* Redraw */
   draw_all_tiles ();
@@ -1393,7 +1393,9 @@ main (int argc, char *argv[])
   if (!games_runtime_init ("mahjongg"))
     return 1;
 
+#ifdef ENABLE_SETGID
   setgid_io_init ();
+#endif
 
   context = g_option_context_new (NULL);
 #if GLIB_CHECK_VERSION (2, 12, 0)
